<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// S
	'sites_description' => 'Sitios y sindicación en SPIP (privado y público)',
	'sites_slogan' => 'Administración de los sitios y de la sindicación en SPIP',
];
